# k_configfile = "configFileName"

# dev keys
packageName = "infobot"
socialModule = "social."
storageModule = "storage."

# storage keys
dataDirectoryKey = "directory"
counterKey = "counterfile"
indexFileFormatKey = "indexformat"

# index related keys
startKey = "start"
lastKey = "last"
previousKey = "previous"

# post format keys
footerKey = "footer"
headerKey = "header"
fakeKey = "fake"
mastodonKey = "mastodon"

# social Keys
useridKey = "userid"
passwdKey = "password"

socialAppKey = "socialapp"
apiURLKey = "apiurl"
clientAppNameKey = "clientappname"
clientSecretKey = "clientsecretfilename"
userSecretKey = "usersecretfilename"
